pub struct WorkflowCancelFailureError { /* private fields */ }Expand description
A normalized external workflow cancellation failure wrapper.
Implementations
Sourceimpl WorkflowCancelFailureError
impl WorkflowCancelFailureError
Sourcepub fn cause(&self) -> Option<&IncomingError>
pub fn cause(&self) -> Option<&IncomingError>
Returns the normalized direct cause of the external workflow cancellation failure, if any.
Sourcepub fn error(&self) -> &IncomingError
pub fn error(&self) -> &IncomingError
Returns the direct decoded incoming error represented by the top-level proto failure.