pub struct WorkflowSignalFailureError { /* private fields */ }Expand description
A normalized workflow signal failure wrapper.
Implementations
Sourceimpl WorkflowSignalFailureError
impl WorkflowSignalFailureError
Sourcepub fn cause(&self) -> Option<&IncomingError>
pub fn cause(&self) -> Option<&IncomingError>
Returns the normalized direct cause of the workflow signal failure, if any.
Sourcepub fn error(&self) -> &IncomingError
pub fn error(&self) -> &IncomingError
Returns the direct decoded incoming error represented by the top-level proto failure.